@@ -2,8 +2,9 @@ from .cdn import AliCdnDomain
 from .nas import AliNas
 from .dds import AliMongoDB
 from .kafka import AliKafka
-from .vpn import AliVpn, AliCustomer, AliIPsec, AliRouteEntry
+from .vpn import AliVpn, AliCustomer, AliIPsec
 from .ess import AliEss
 from .vpc import AliVpc
 from .cs import AliCs
+from .nat import AliNatDomain
 
