@@ -5,6 +5,7 @@ from .dds_client import DdsClient
 from .kafka_client import KafkaClient
 from .order_client import OrderClient
 from .vpn_client import VpnGatewayClient
+from .nat_client import NatClient
 from proxy_tools import proxy
 from .ess_client import EssClient
 from .vpc_client import VpcClient
@@ -19,7 +20,8 @@ prod_mapper = {
     'vpn': VpnGatewayClient,
     'ess': EssClient,
     'vpc': VpcClient,
-    'cs': CsClient
+    'cs': CsClient,
+    'nat': NatClient
 }
 
 
@@ -72,4 +74,9 @@ def vpc_client():
 
 @proxy
 def cs_client():
-    return get_current_client('cs')
\ No newline at end of file
+    return get_current_client('cs')
+
+
+@proxy
+def nat_client():
+    return get_current_client('nat')
\ No newline at end of file
