@@ -26,15 +26,16 @@ class AliNas:
             return None
 
     @classmethod
-    def list(cls):
+    def list(cls, set_params=None):
         response = []
+
         while True:
             page = 1
             params = {
                 "PageSize": 100,
                 "PageNumber": page
             }
-            ret = nas_client.describe_file_systems(params)
+            ret = nas_client.describe_file_systems(params, set_params=set_params)
             response.extend(ret['FileSystems']['FileSystem'])
             if int(ret['PageNumber']) * int(ret['PageSize']) > int(ret['TotalCount']):
                 break
@@ -93,6 +94,10 @@ class AliNas:
     def created_time(self):
         return self.nas_info.get('CreateTime').replace('CST', ' ').replace('T', ' ')
 
+    @property
+    def tags(self):
+        return self.nas_info.get('Tags')
+
     def create_mount_target(self, query_params):
         query_params.update({
             "FileSystemId": self.external_id
